@@ -19,6 +19,7 @@ class TestMessagingView(RapidTest):
 
     def test_get(self):
         """The messaging page should return a 200 code."""
+        self.login()
         response = self.client.get(self.url)
         self.assertEqual(response.status_code, 200)
 
@@ -47,11 +48,13 @@ class TestSendView(RapidTest):
 
     def test_get(self):
         """Only POST should be allowed."""
+        self.login()
         response = self.client.get(self.url)
         self.assertEqual(response.status_code, 405)  # Method Not Allowed
 
     def test_post(self):
         """Posting valid data should cause a 200 response."""
+        self.login()
         response = self.client.post(self.url, self.data)
         self.assertEqual(response.status_code, 200)
         self.assertEqual(len(self.outbound), 1)
@@ -63,12 +66,14 @@ class TestSendView(RapidTest):
     def test_post_no_message(self):
         """A form validation error should cause a 400 response."""
         self.data.pop('message')
+        self.login()
         response = self.client.post(self.url, self.data)
         self.assertEqual(response.status_code, 400)  # Bad Request
 
     def test_post_no_contacts(self):
         """A form validation error should cause a 400 response."""
         self.data.pop('connections_1')
+        self.login()
         response = self.client.post(self.url, self.data)
         self.assertEqual(response.status_code, 400)  # Bad Request
 
@@ -77,7 +82,9 @@ class TestSendView(RapidTest):
         An error during sending should cause a 500 response. No guarantees
         are made about whether the message has been sent to other recipients.
         """
-        with mock.patch('rapidsms.contrib.messaging.forms.MessageForm.send') as send:
+        with mock.patch('rapidsms.contrib.messaging.forms.MessageForm.send')\
+                as send:
             send.side_effect = Exception()
+            self.login()
             response = self.client.post(self.url, self.data)
         self.assertEqual(response.status_code, 500)
